@@ -46,6 +46,8 @@ V1_10_20 = 'v1.10.20'
 V1_10_21 = 'v1.10.21'
 V1_10_22 = 'v1.10.22'
 V1_10_23 = 'v1.10.23'
+V1_10_24 = 'v1.10.24'
+V1_10_25 = 'v1.10.25'
 
 
 LINUX = 'linux'
@@ -241,13 +243,34 @@ def extract_source_code_release(identifier):
     source_code_extract_path = get_source_code_extract_path(identifier)
     ensure_path_exists(source_code_extract_path)
 
-    print("Extracting archive: {0} -> {1}".format(
-        source_code_archive_path,
-        source_code_extract_path,
-    ))
+    print(
+        "Extracting archive: {0} -> {1}".format(
+            source_code_archive_path,
+            source_code_extract_path,
+        )
+    )
 
-    with tarfile.open(source_code_archive_path, 'r:gz') as archive_file:
-        archive_file.extractall(source_code_extract_path)
+    with tarfile.open(source_code_archive_path, "r:gz") as archive_file:
+
+        def is_within_directory(directory, target):
+
+            abs_directory = os.path.abspath(directory)
+            abs_target = os.path.abspath(target)
+
+            prefix = os.path.commonprefix([abs_directory, abs_target])
+
+            return prefix == abs_directory
+
+        def safe_extract(tar, path="."):
+
+            for member in tar.getmembers():
+                member_path = os.path.join(path, member.name)
+                if not is_within_directory(path, member_path):
+                    raise Exception("Attempted Path Traversal in Tar File")
+
+            tar.extractall(path)
+
+        safe_extract(archive_file, source_code_extract_path)
 
 
 def build_from_source_code(identifier):
@@ -344,6 +367,8 @@ install_v1_10_20 = functools.partial(install_from_source_code_release, V1_10_20)
 install_v1_10_21 = functools.partial(install_from_source_code_release, V1_10_21)
 install_v1_10_22 = functools.partial(install_from_source_code_release, V1_10_22)
 install_v1_10_23 = functools.partial(install_from_source_code_release, V1_10_23)
+install_v1_10_24 = functools.partial(install_from_source_code_release, V1_10_24)
+install_v1_10_25 = functools.partial(install_from_source_code_release, V1_10_25)
 
 
 INSTALL_FUNCTIONS = {
@@ -384,6 +409,8 @@ INSTALL_FUNCTIONS = {
         V1_10_21: install_v1_10_21,
         V1_10_22: install_v1_10_22,
         V1_10_23: install_v1_10_23,
+        V1_10_24: install_v1_10_24,
+        V1_10_25: install_v1_10_25,
     },
     OSX: {
         V1_9_14: install_v1_9_14,
@@ -422,6 +449,8 @@ INSTALL_FUNCTIONS = {
         V1_10_21: install_v1_10_21,
         V1_10_22: install_v1_10_22,
         V1_10_23: install_v1_10_23,
+        V1_10_24: install_v1_10_24,
+        V1_10_25: install_v1_10_25,
     }
 }
 
